==> gazie7.30.zip: gazie/modules/inform/downlo_backup.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
require("../../library/include/datlib.inc.php");
$admin_aziend=checkAdmin();

//require("../../library/include/header.php");
//$script_transl=HeadMain('','','report_backup');

$url= "../../data/files/backups/";
    $id_file= $_GET["id"];
    $total=$url.$id_file;
    header("Pragma: no-cache");
    header("Expires: 0");
    Header("Content-Type: application/octet-stream");
    Header("Content-Length: ".filesize($total));
    Header("Content-Disposition: attachment; filename=\"".$_GET["id"]."\"");
    readfile($total);

if (isset($_POST['Return'])){
    header("Location: report_backup.php");
    exit;
}

?>

==> gazie8.00.zip: gazie/modules/inform/downlo_backup.php <==
<?php
/*
 --------------------------------------------------------------------------
                            GAzie - Gestione Azienda
    Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
         (http://www.devincentiis.it)
           <http://gazie.sourceforge.net>
 --------------------------------------------------------------------------
    Questo programma e` free software;   e` lecito redistribuirlo  e/o
    modificarlo secondo i  termini della Licenza Pubblica Generica GNU
    come e` pubblicata dalla Free Software Foundation; o la versione 2
    della licenza o (a propria scelta) una versione successiva.

    Questo programma  e` distribuito nella speranza  che sia utile, ma
    SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
    NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
    veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

    Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
    Generica GNU insieme a   questo programma; in caso  contrario,  si
    scriva   alla   Free  Software Foundation, 51 Franklin Street,
    Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
 --------------------------------------------------------------------------
*/
require("../../library/include/datlib.inc.php");
$admin_aziend=checkAdmin();

//require("../../library/include/header.php");
//$script_transl=HeadMain('','','report_backup');

$url= DATA_DIR."files/backups/";
    $id_file= $_GET["id"];
    $total=$url.$id_file;
    header("Pragma: no-cache");
    header("Expires: 0");
    Header("Content-Type: application/octet-stream");
    Header("Content-Length: ".filesize($total));
    Header("Content-Disposition: attachment; filename=\"".$_GET["id"]."\"");
    readfile($total);

if (isset($_POST['Return'])){
    header("Location: report_backup.php");
    exit;
}

?>
